Feedforward Closedloop Learning: Class Members

Feedforward Closedloop Learning

Here is a list of all documented class members with links to the class documentation for each member:

### - d -

- dActivation() : feedforward_closedloop_learning.Neuron , Neuron
- doLearning() : feedforward_closedloop_learning.Layer , feedforward_closedloop_learning.Neuron , Layer , Neuron
- doLearningThread() : feedforward_closedloop_learning.Neuron , Neuron
- doMaxDet() : feedforward_closedloop_learning.Neuron , Neuron
- doMaxDetThread() : feedforward_closedloop_learning.Neuron , Neuron
- doNormaliseWeights() : feedforward_closedloop_learning.Layer , Layer
- doStep() : feedforward_closedloop_learning.FeedforwardClosedloopLearning , feedforward_closedloop_learning.FeedforwardClosedloopLearningWithFilterbank , FeedforwardClosedloopLearning , FeedforwardClosedloopLearningWithFilterbank